@@ -1,6 +1,7 @@
 -- -*-sql-*- 
 --
--- Copyright (C) 2008 Loic Dachary <loic@dachary.org>
+-- Copyright (C) 2008, 2009 Loic Dachary <loic@dachary.org>
+-- Copyright (C)       2009 Johan Euphrosine <proppy@aminche.com>
 -- Copyright (C) 2004, 2005, 2006 Mekensleep <licensing@mekensleep.com>
 --                                24 rue vieille du temple, 75004 Paris
 --
@@ -33,7 +34,7 @@ CREATE TABLE server (
   version VARCHAR(16) NOT NULL
 ) ENGINE=InnoDB CHARSET=utf8;
 
-INSERT INTO server (version) VALUES ("1.7.4");
+INSERT INTO server (version) VALUES ("1.7.7");
 
 DROP TABLE IF EXISTS users;
 
@@ -175,8 +176,11 @@ CREATE TABLE pokertables (
   tourney_serial INT UNSIGNED DEFAULT 0 NOT NULL,
 
   PRIMARY KEY (serial),
-  KEY (name),
-  KEY (variant),
+  KEY pokertables_name (name),
+  KEY pokertables_variant (variant),
+  KEY pokertables_players (players),
+  KEY pokertables_betting_structure (betting_structure),
+  KEY pokertables_currency_serial (currency_serial),
   KEY (resthost_serial)
 )  ENGINE=InnoDB CHARSET=utf8;
 
@@ -249,6 +253,8 @@ CREATE TABLE tourneys_schedule (
   player_timeout INT DEFAULT 60,
   -- Serial of the currency required to pay the buyin.
   currency_serial INT,
+  -- Serial of the currency in which the prizes will be payed (same as currency_serial if zero)
+  prize_currency INT UNSIGNED DEFAULT 0,
   -- Minimum prize pool in cents.
   prize_min INT DEFAULT 0,
   -- Serial number of the player (serial field of the users table) 
@@ -275,7 +281,6 @@ CREATE TABLE tourneys_schedule (
   add_on_delay INT DEFAULT 60,
   -- Unix timestamp of the tournament start.
   start_time INT DEFAULT 0,
-
   -- Unix timestamp of the registration start.
   register_time INT DEFAULT 0,
   -- n : the tournament is ignored by the server, y : the tournament
@@ -286,10 +291,50 @@ CREATE TABLE tourneys_schedule (
   respawn CHAR DEFAULT 'n',
   -- Unused.
   respawn_interval INT DEFAULT 0,
-  -- Format string to override currency serial from date 
-  -- The string can only contain %Y (2008) %m (03) or %d (07)
+  -- Format string to override the currency_serial field from date 
+  -- %d 	Day of the month as a decimal number [01,31]. 	 
+  -- %H 	Hour (24-hour clock) as a decimal number [00,23]. 	 
+  -- %I 	Hour (12-hour clock) as a decimal number [01,12]. 	 
+  -- %j 	Day of the year as a decimal number [001,366]. 	 
+  -- %m 	Month as a decimal number [01,12]. 	 
+  -- %M 	Minute as a decimal number [00,59]. 	 
+  -- %S 	Second as a decimal number [00,61]. 
+  -- %U 	Week number of the year (Sunday as the first day of the week) as a decimal number [00,53]. All days in a new year preceding the first Sunday are considered to be in week 0.
+  -- %w 	Weekday as a decimal number [0(Sunday),6]. 	 
+  -- %W 	Week number of the year (Monday as the first day of the week) as a decimal number [00,53]. All days in a new year preceding the first Monday are considered to be in week 0.
+  -- %y 	Year without century as a decimal number [00,99]. 	 
+  -- %Y 	Year with century as a decimal number. 	 
+  -- The string can only contain the placeholders documented above
   -- Example: '%Y%m' 
+  --
   currency_serial_from_date_format VARCHAR(16) DEFAULT NULL,
+  --
+  -- Format string to override the prize_currency field from date.
+  -- The semantics is the same as currency_serial_from_date_format.
+  --
+  prize_currency_from_date_format VARCHAR(16) DEFAULT NULL,
+  --
+  -- If 0 the tournament is not a satellite, if > 0 the tournament
+  -- is a satellite and satellite_player_count is
+  -- taken into account. The value is a reference to the serial  
+  -- field of the tourneys_schedule table. 
+  --
+  satellite_of INT UNSIGNED DEFAULT 0,
+  --
+  -- If 1 the users cannot register to the tournament unless they
+  -- participated in a satellite. See the TourneyRegister packet
+  -- for more information. If 0 the users can register if they pay
+  -- the buyin.
+  -- 
+  via_satellite TINYINT DEFAULT 0,
+  --
+  -- The number of tournament winners that will be registered to the
+  -- satellite_of tournament. The winners that are already registered
+  -- to satellite_of are ignored. If satellite_player_count is 10 
+  -- and 2 of the top 10 are already registered, the remaining 2
+  -- will be drawn from the top 12 winners.
+  --
+  satellite_player_count INT UNSIGNED DEFAULT 0,
 
   PRIMARY KEY (serial),
   KEY tourneys_schedule_active_index (active),
@@ -393,6 +438,7 @@ CREATE TABLE tourneys (
   seats_per_game INT DEFAULT 10,
   player_timeout INT DEFAULT 60,
   currency_serial INT,
+  prize_currency INT UNSIGNED DEFAULT 0,
   prize_min INT DEFAULT 0,
   bailor_serial INT DEFAULT 0,
   buy_in INT DEFAULT 0,
@@ -405,6 +451,9 @@ CREATE TABLE tourneys (
   add_on INT DEFAULT 0,
   add_on_delay INT DEFAULT 60,
   start_time INT DEFAULT 0,
+  satellite_of INT UNSIGNED DEFAULT 0,
+  via_satellite TINYINT DEFAULT 0,
+  satellite_player_count INT UNSIGNED DEFAULT 0,
 
   finish_time INT DEFAULT 0,
   state VARCHAR(16) DEFAULT "registering",
@@ -505,6 +554,19 @@ CREATE TABLE messages (
   PRIMARY KEY (serial, send_date, sent)
 ) ENGINE=InnoDB CHARSET=utf8;
 
+
+DROP TABLE IF EXISTS chat_messages;
+
+CREATE TABLE chat_messages (
+  serial INT UNSIGNED NOT NULL AUTO_INCREMENT,
+  player_serial INT UNSIGNED NOT NULL,
+  game_id INT UNSIGNED NOT NULL,
+  message TEXT DEFAULT '',
+  timestamp TIMESTAMP DEFAULT CURRENT_TIMESTAMP,  
+
+  PRIMARY KEY (serial)
+) ENGINE=MyISAM CHARSET=utf8;
+
 DROP TABLE IF EXISTS monitor;
 
 CREATE TABLE monitor (
