@@ -1,8 +1,8 @@
 #
 # -*- coding: iso-8859-1 -*-
 #
-# Copyright (C) 2006, 2007, 2008 Loic Dachary <loic@dachary.org>
-# Copyright (C)             2008 Bradley M. Kuhn <bkuhn@ebb.org>
+# Copyright (C) 2006, 2007, 2008, 2009 Loic Dachary <loic@dachary.org>
+# Copyright (C)       2008, 2009 Bradley M. Kuhn <bkuhn@ebb.org>
 # Copyright (C)             2008 Johan Euphrosine <proppy@aminche.com>
 # Copyright (C) 2004, 2005, 2006 Mekensleep
 #                                24 rue vieille du temple 75004 Paris
@@ -31,6 +31,7 @@
 
 from string import join
 import sets
+import re
 
 from twisted.internet import defer
 
@@ -262,7 +263,10 @@ class PokerAvatar:
         queue = self._packets_queue
         self._packets_queue = []
         return queue
-    
+
+    def removeGamePacketsQueue(self, game_id):
+        self._packets_queue = filter(lambda packet: not hasattr(packet, "game_id") or packet.game_id != game_id, self._packets_queue)
+
     def sendPacket(self, packet):
         from pokerengine.pokergame import init_i18n as pokergame_init_i18n
         # Note on special processing of locales on packet send:
@@ -461,7 +465,7 @@ class PokerAvatar:
                                                        code = PACKET_POKER_PLAYER_IMAGE,
                                                        message = "Failed to save set player image"))
             else:
-                self.message("attempt to set player info for player %d by player %d" % ( packet.serial, self.getSerial() ))
+                self.message("attempt to set player image for player %d by player %d" % ( packet.serial, self.getSerial() ))
             return
                 
         elif packet.type == PACKET_POKER_PERSONAL_INFO:
@@ -508,6 +512,14 @@ class PokerAvatar:
             self.sendPacketVerbose(self.service.setAccount(packet))
             return
 
+        elif packet.type == PACKET_POKER_CREATE_TOURNEY:
+            if self.getSerial() == packet.serial:
+                self.sendPacketVerbose(self.service.tourneyCreate(packet))
+            else:
+                self.message("attempt to create tourney for player %d by player %d" % ( packet.serial, self.getSerial() ))
+                self.sendPacketVerbose(PacketAuthRequest())
+            return
+
         if packet.type == PACKET_POKER_TOURNEY_SELECT:
             ( playerCount, tourneyCount ) = self.service.tourneyStats()
             tourneyList = PacketPokerTourneyList(players = playerCount,
@@ -570,12 +582,13 @@ class PokerAvatar:
             return
 
         elif packet.type == PACKET_POKER_TABLE_JOIN:
-            table = self.service.getTable(packet.game_id)
-            if table:
-                if not table.joinPlayer(self, self.getSerial()):
-                    self.sendPacketVerbose(PacketPokerTable())
+            self.performPacketPokerTableJoin(packet)
+
             return
 
+        elif packet.type == PACKET_POKER_TABLE_PICKER:
+            self.performPacketPokerTablePicker(packet)
+            return
 
         table = self.packet2table(packet)
             
@@ -620,32 +633,10 @@ class PokerAvatar:
                     self.message("player %d tried to start a new game but is not the owner of the table" % self.getSerial())
 
             elif packet.type == PACKET_POKER_SEAT:
-                if PacketPokerRoles.PLAY not in self.roles:
-                    self.sendPacketVerbose(PacketPokerError(game_id = game.id,
-                                                            serial = packet.serial,
-                                                            code = PacketPokerSeat.ROLE_PLAY,
-                                                            message = "PACKET_POKER_ROLES must set the role to PLAY before chosing a seat",
-                                                            other_type = PACKET_POKER_SEAT))
-                elif ( self.getSerial() == packet.serial or
-                     self.getSerial() == table.owner ):
-                    if not table.seatPlayer(self, packet.serial, packet.seat):
-                        packet.seat = -1
-                    else:
-                        packet.seat = game.getPlayer(packet.serial).seat
-                    self.getUserInfo(packet.serial)
-                    self.sendPacketVerbose(packet)
-                else:
-                    self.message("attempt to get seat for player %d by player %d that is not the owner of the game" % ( packet.serial, self.getSerial() ))
-                
+                self.performPacketPokerSeat(packet, table, game)
+
             elif packet.type == PACKET_POKER_BUY_IN:
-                if self.getSerial() == packet.serial:
-                    self.service.autorefill(packet.serial)
-                    if not table.buyInPlayer(self, packet.amount):
-                        self.sendPacketVerbose(PacketPokerError(game_id = game.id,
-                                                                serial = packet.serial,
-                                                                other_type = PACKET_POKER_BUY_IN))
-                else:
-                    self.message("attempt to bring money for player %d by player %d" % ( packet.serial, self.getSerial() ))
+                self.performPacketPokerBuyIn(packet, table, game)
 
             elif packet.type == PACKET_POKER_REBUY:
                 if self.getSerial() == packet.serial:
@@ -670,10 +661,7 @@ class PokerAvatar:
                     self.message("attempt to leave for player %d by player %d that is not the owner of the game" % ( packet.serial, self.getSerial() ))
 
             elif packet.type == PACKET_POKER_SIT:
-                if self.getSerial() == packet.serial or self.getSerial() == table.owner:
-                    table.sitPlayer(self, packet.serial)
-                else:
-                    self.message("attempt to sit back for player %d by player %d that is not the owner of the game" % ( packet.serial, self.getSerial() ))
+                self.performPacketPokerSit(packet, table)
                 
             elif packet.type == PACKET_POKER_SIT_OUT:
                 if self.getSerial() == packet.serial or self.getSerial() == table.owner:
@@ -771,14 +759,17 @@ class PokerAvatar:
             table.update()
 
         elif not table and packet.type == PACKET_POKER_HAND_REPLAY:
-            table = self.createTable(PacketPokerTable())
+            table = self.createTable(PacketPokerTable(
+                        reason = PacketPokerTable.REASON_HAND_REPLAY))
             if table:
                 table.handReplay(self, packet.serial)
 
         elif packet.type == PACKET_POKER_TABLE:
+            packet.reason = PacketPokerTable.REASON_TABLE_CREATE
             table = self.createTable(packet)
             if table:
-                table.joinPlayer(self, self.getSerial())
+                table.joinPlayer(self, self.getSerial(),
+                                 reason = PacketPokerTable.REASON_TABLE_CREATE)
             
         elif packet.type == PACKET_QUIT:
             for table in self.tables.values():
@@ -793,7 +784,166 @@ class PokerAvatar:
                 self.sendPacketVerbose(PacketError(code = PacketLogout.NOT_LOGGED_IN,
                                                    message = "Not logged in",
                                                    other_type = PACKET_LOGOUT))
-            
+
+    # The "perform" methods below are designed so that the a minimal
+    # amount of code related to receiving a packet that appears in the
+    # handlePacketLogic() giant if statement above.  The primary motive
+    # for this is for things like PacketTablePicker(), that need to
+    # perform operations *as if* the client has sent additional packets.
+    # The desire is to keep completely parity between what the individual
+    # packets do by themselves, and what "super-packets" like
+    # PacketTablePicker() do.  A secondary benefit is that it makes that
+    # giant if statement in handlePacketLogic() above a bit smaller.
+    # -------------------------------------------------------------------------
+    def performPacketPokerTableJoin(self, packet, table = None,
+                                    deprecatedEmptyTableBehavior = True,
+                                    requestorPacketType = PACKET_POKER_TABLE_JOIN,
+                                    reason = PacketPokerTable.REASON_TABLE_JOIN):
+        """Perform the operations that must occur when a
+        PACKET_POKER_TABLE_JOIN is received."""
+        
+        if not table:
+            table = self.service.getTable(packet.game_id)
+        if table:
+            self.removeGamePacketsQueue(packet.game_id)
+            if not table.joinPlayer(self, self.getSerial(),
+                                    reason = reason):
+                if deprecatedEmptyTableBehavior:
+                    self.sendPacketVerbose(PacketPokerTable(reason = reason))
+                self.sendPacketVerbose(
+                  PacketPokerError(code = PacketPokerTableJoin.GENERAL_FAILURE,
+                                   message = "Unable to join table for unknown reason",
+                                   other_type = requestorPacketType,
+                                   serial     = self.getSerial(),
+                                   game_id    = 0))
+        return table
+    # -------------------------------------------------------------------------
+    def performPacketPokerSeat(self, packet, table, game):
+        """Perform the operations that must occur when a PACKET_POKER_SEAT
+        is received."""
+
+        if PacketPokerRoles.PLAY not in self.roles:
+            self.sendPacketVerbose(PacketPokerError(game_id = game.id,
+                                                    serial = packet.serial,
+                                                    code = PacketPokerSeat.ROLE_PLAY,
+                                                    message = "PACKET_POKER_ROLES must set the role to PLAY before chosing a seat",
+                                                    other_type = PACKET_POKER_SEAT))
+            return False
+        elif ( self.getSerial() == packet.serial or self.getSerial() == table.owner ):
+            if not table.seatPlayer(self, packet.serial, packet.seat):
+                packet.seat = -1
+            else:
+                packet.seat = game.getPlayer(packet.serial).seat
+            self.getUserInfo(packet.serial)
+            self.sendPacketVerbose(packet)
+            return (packet.seat != -1)
+        else:
+            self.message("attempt to get seat for player %d by player %d that is not the owner of the game" % ( packet.serial, self.getSerial() ))
+            return False
+    # -------------------------------------------------------------------------
+    def performPacketPokerBuyIn(self, packet, table, game):
+        if self.getSerial() == packet.serial:
+            self.service.autorefill(packet.serial)
+            if not table.buyInPlayer(self, packet.amount):
+                self.sendPacketVerbose(PacketPokerError(game_id = game.id,
+                                                        serial = packet.serial,
+                                                        other_type = PACKET_POKER_BUY_IN))
+                return False
+            else:
+                return True
+        else:
+            self.message("attempt to bring money for player %d by player %d" % ( packet.serial, self.getSerial() ))
+            return False
+    # -------------------------------------------------------------------------
+    def performPacketPokerSit(self, packet, table):
+        if self.getSerial() == packet.serial or self.getSerial() == table.owner:
+            table.sitPlayer(self, packet.serial)
+            return True
+        else:
+            self.message("attempt to sit back for player %d by player %d that is not the owner of the game" % ( packet.serial, self.getSerial() ))
+            return False
+    # -------------------------------------------------------------------------
+    def performPacketPokerTablePicker(self, packet):
+        mySerial = self.getSerial()
+        if mySerial != packet.serial:
+            errMsg = "attempt to run table picker for player %d by player %d" % ( packet.serial, mySerial )
+            self.message(errMsg)
+            self.sendPacketVerbose(
+                PacketPokerError(code       = PacketPokerTableJoin.GENERAL_FAILURE,
+                                 message    = errMsg,
+                                 other_type = PACKET_POKER_TABLE_PICKER,
+                                 serial     = mySerial,
+                                 game_id    = 0))
+        else:
+            # Call autorefill() first before checking for a table,
+            # since the amount of money we have left will impact the
+            # table selection, and in a play-money scenario, we want
+            # to have whatever play-money we can get before picking.
+            self.service.autorefill(packet.serial)
+
+            table = self.service.getTableBestByCriteria(mySerial,
+                      min_players = packet.min_players, currency_serial = packet.currency_serial,
+                      variant = packet.variant, betting_structure = packet.betting_structure)
+
+            if not table:
+                # If we cannot find a table, tell user we were unable to
+                # find a table matching their criteria
+                self.sendPacketVerbose(
+                  PacketPokerError(code       = PacketPokerTableJoin.GENERAL_FAILURE,
+                                   message    = "No table found matching given criteria",
+                                   other_type = PACKET_POKER_TABLE_PICKER,
+                                   serial     = mySerial,
+                                   game_id    = 0))
+            elif not table.game.canAddPlayer(mySerial):
+                # If the table we found just can't take us, tell user we
+                # could not add them.
+                self.sendPacketVerbose(
+                  PacketPokerError(code      = PacketPokerTableJoin.GENERAL_FAILURE,
+                                   message   = "Found matching table, but unable to join it.",
+                                   other_type = PACKET_POKER_TABLE_PICKER,
+                                   serial     = mySerial,
+                                   game_id    = table.game.id))
+            else:
+                # Otherwise, we perform the sequence of operations
+                # that is defined by the semantics of this packet in
+                # pokerpacket.py.  Basically, we perform:
+                #   PacketTableJoin(), and if it succeeds,
+                #   PacketPokerSeat(), and if it succeeds,
+                #   We figure out our best buy-in choice, buyIn, then perform:
+                #   PacketPokerBuyIn(amount = buyIn), and if it succeeds, 
+                #   PacketPokerSit()
+                if self.performPacketPokerTableJoin(
+                     PacketPokerTableJoin(serial = mySerial,
+                                          game_id = table.game.id), table,
+                       deprecatedEmptyTableBehavior = False,
+                       reason = PacketPokerTable.REASON_TABLE_PICKER):
+
+                    # Giving no seat argument at all for the packet should cause
+                    # us to get any available seat.
+                    if self.performPacketPokerSeat(
+                        PacketPokerSeat(serial = mySerial, game_id = table.game.id),
+                        table, table.game):
+
+                        # Next, determine if player can afford the "best"
+                        # buy in.  If the player can't, give them the
+                        # minimum buyin.
+
+                        buyIn = table.game.bestBuyIn()
+                        if self.service.getMoney(mySerial, table.currency_serial) < buyIn:
+                            buyIn = table.game.buyIn()
+                            # No need to check above if we have that,
+                            # since our answer on this table came from
+                            # self.service.getTableByBestCriteria(), which
+                            # promises us that we have at least minimum.
+                        if self.performPacketPokerBuyIn(
+                            PacketPokerBuyIn(serial = mySerial, amount = buyIn,
+                                 game_id = table.game.id), table, table.game):
+                            if packet.auto_blind_ante:
+                                table.autoBlindAnte(self, packet.serial, True)
+                            self.performPacketPokerSit(
+                               PacketPokerSit(serial = mySerial, game_id = table.game.id),
+                               table)
+    # -------------------------------------------------------------------------
     def setPlayerInfo(self, packet):
         self.user.url = packet.url
         self.user.outfit = packet.outfit
@@ -861,6 +1011,7 @@ class PokerAvatar:
                                       waiting = int(table['waiting']),
                                       skin = table['skin'],
                                       currency_serial = int(table['currency_serial']),
+                                      reason = PacketPokerTable.REASON_TABLE_LIST,
                                       )
             packet.tourney_serial = int(table['tourney_serial'])
             packets.append(packet)
@@ -910,17 +1061,20 @@ class PokerAvatar:
             "player_timeout": packet.player_timeout,
             "muck_timeout": packet.muck_timeout,
             "currency_serial": packet.currency_serial,
-            "skin": packet.skin })
+            "skin": packet.skin,
+            "reason" : packet.reason})
         if not table:
-            self.sendPacket(PacketPokerTable())
+            self.sendPacket(PacketPokerTable(reason = packet.reason))
         return table            
 
-    def join(self, table):
+    def join(self, table, reason = ""):
         game = table.game
         
         self.tables[game.id] = table
 
-        self.sendPacketVerbose(table.toPacket())
+        packet = table.toPacket()
+        packet.reason = reason
+        self.sendPacketVerbose(packet)
         self.sendPacketVerbose(PacketPokerBuyInLimits(game_id = game.id,
                                                       min = game.buyIn(),
                                                       max = game.maxBuyIn(),
