@@ -2,30 +2,27 @@
 # -*- py-indent-offset: 4; coding: iso-8859-1 -*-
 #
 # Copyright (C) 2006, 2007, 2008 Loic Dachary <loic@dachary.org>
-# Copyright (C) 2008 Bradley M. Kuhn <bkuhn@ebb.org>
-# Copyright (C) 2006 Mekensleep
+# Copyright (C) 2008             Bradley M. Kuhn <bkuhn@ebb.org>
+# Copyright (C) 2006 Mekensleep <licensing@mekensleep.com>
+#                    24 rue vieille du temple, 75004 Paris
 #
-# Mekensleep
-# 24 rue vieille du temple
-# 75004 Paris
-#       licensing@mekensleep.com
+# This software's license gives you freedom; you can copy, convey,
+# propagate, redistribute and/or modify this program under the terms of
+# the GNU Affero General Public License (AGPL) as published by the Free
+# Software Foundation (FSF), either version 3 of the License, or (at your
+# option) any later version of the AGPL published by the FSF.
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3 of the License, or
-# (at your option) any later version.
+# This program is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero
+# General Public License for more details.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA.
+# You should have received a copy of the GNU Affero General Public License
+# along with this program in a file in the toplevel directory called
+# "AGPLv3".  If not, see <http://www.gnu.org/licenses/>.
 #
 # Authors:
-#  Loic Dachary <loic@gnu.org>
+#  Loic Dachary <loic@dachary.org>
 #
 
 from MySQLdb.constants import ER
@@ -88,6 +85,8 @@ class PokerCashier:
                 cursor.execute(sql, url)
                 if cursor.rowcount == 1:
                     currency_serial = cursor.lastrowid
+                else:
+                    raise Exception("SQL command '%s' failed without raising exception.  Underlying DB may be severely hosed" % sql)
             except Exception, e:
                 cursor.close()
                 if e[0] == ER.DUP_ENTRY and reentrant:
@@ -311,7 +310,7 @@ class PokerCashier:
         return deferred
         
     def cashOutUpdateCounter(self, new_notes, packet):
-        if self.verbose > 2: self.message("cashOuUpdateCounter: new_notes = " + str(new_notes) + " packet = " + str(packet))
+        if self.verbose > 2: self.message("cashOutUpdateCounter: new_notes = " + str(new_notes) + " packet = " + str(packet))
         cursor = self.db.cursor()
         if len(new_notes) != 2:
             raise PacketError(other_type = PACKET_POKER_CASH_OUT,
@@ -370,7 +369,8 @@ class PokerCashier:
                 if self.verbose > 2: self.message(sql)
                 cursor.execute(sql)
                 if cursor.rowcount != 1:
-                    self.error(sql + " found " + str(cursor.rowcount) + " records instead of exactly 1")
+                    message = sql + " found " + str(cursor.rowcount) + " records instead of exactly 1"
+                    self.error(message)
                     raise PacketError(other_type = PACKET_POKER_CASH_OUT,
                                       code = PacketPokerCashOut.SAFE,
                                       message = message)
@@ -393,10 +393,10 @@ class PokerCashier:
     def unlock(self, currency_serial):
         name = self.getLockName(currency_serial)
         if not self.locks.has_key(name):
-            if self.verbose: self.error("cashInUnlock: unpexected missing " + name + " in locks (ignored)")
+            if self.verbose: self.error("cashInUnlock: unexpected missing " + name + " in locks (ignored)")
             return
         if not self.locks[name].isAlive():
-            if self.verbose: self.error("cashInUnlock: unpexected dead " + name + " pokerlock (ignored)")
+            if self.verbose: self.error("cashInUnlock: unexpected dead " + name + " pokerlock (ignored)")
             return
         self.locks[name].release(name)
 
