@@ -820,9 +820,36 @@ game_id: integer uniquely identifying a game.
 
 Packet.infoDeclare(globals(), PacketPokerAllinShowdown, Packet, "POKER_ALLIN_SHOWDOWN", 209) # 0xd1 # %SEQ%
 
+########################################
+
+class PacketPokerPlayerHandStrength(PacketPokerId):
+    """\
+Semantics: "hand" is the human-readable description of the best
+possible poker hand the player (represented by "serial") can currently
+make in current hand being played in game, "game_id".  This
+description includes only 'made' poker hands, not draws or potential
+hands.  This description will be sent in the the language of the
+players currently set locale (see PacketPokerSetLocale()), or "en.US"
+if no translation is available.
+
+Direction: client <=> client
+
+Context: inferred on each street.
+
+serial: integer uniquely identifying a player.
+game_id: integer uniquely identifying a game.
+hand: readable player best hand.
+"""
+
+    info = PacketPokerId.info + (
+        ('hand', '', 's'),
+        )
+
+Packet.infoDeclare(globals(), PacketPokerPlayerHandStrength, PacketPokerId, "POKER_PLAYER_HAND_STRENGTH", 210) # 0xd2 # %SEQ%
+
 _TYPES = range(170,254)
 
 # Interpreted by emacs
 # Local Variables:
-# compile-command: "perl -pi -e 'if(/%SEQ%/) { $s = 169 if(!defined($s)); $s++; $h = sprintf(q/0x%x/, $s); s/\\d+[) \\w#]+#/$s # $h #/; }' pokerclientpackets.py"
+# compile-command: "perl -pi -e 'if(/%SEQ%/) { $s = 169 if(!defined($s)); $s++; $h = sprintf(q/0x%x/, $s); s/\\d+[) \\w#]+#/$s) # $h #/; }' pokerclientpackets.py"
 # End:
