@@ -1,7 +1,7 @@
 #
 # -*- coding: iso-8859-1 -*-
 #
-# Copyright (C) 2007, 2008 Loic Dachary <loic@dachary.org>
+# Copyright (C) 2007, 2008, 2009 Loic Dachary <loic@dachary.org>
 # Copyright (C) 2004, 2005, 2006 Mekensleep <licensing@mekensleep.com>
 #                                24 rue vieille du temple, 75004 Paris
 #
@@ -48,7 +48,8 @@ class PokerDatabase:
                                       port = int(self.parameters.get("port", '3306')),
                                       user = self.parameters["user"],
                                       passwd = self.parameters["password"],
-                                      db = self.parameters["name"])
+                                      db = self.parameters["name"],
+                                      reconnect = 1)
             if self.verbose > 2:
                 self.message("MySQL server version is " + self.db.get_server_info())
         except:
@@ -58,7 +59,8 @@ class PokerDatabase:
                 db = MySQLdb.connect(host = self.parameters["host"],
                                      port = int(self.parameters.get("port", '3306')),
                                      user = self.parameters["root_user"],
-                                     passwd = self.parameters["root_password"])
+                                     passwd = self.parameters["root_password"],
+                                     reconnect = 1)
                 if self.verbose:
                     self.message("MySQL server version is " + db.get_server_info())
                 if int(db.get_server_info().split('.')[0]) < 5:
@@ -117,7 +119,8 @@ class PokerDatabase:
                                       port = int(self.parameters.get("port", '3306')),
                                       user = self.parameters["user"],
                                       passwd = self.parameters["password"],
-                                      db = self.parameters["name"])
+                                      db = self.parameters["name"],
+                                      reconnect = 1)
 
         if self.verbose:
             self.message("PokerDatabase: Database connection to %s/%s open" % ( self.parameters["host"], self.parameters["name"] ))
