@@ -236,6 +236,8 @@ class PokerExplain:
 
     def handleSerial(self, packet):
         self.serial = packet.serial
+        if self._prefix == '':
+            self.setPrefix('[%i]' % packet.serial)
 
     def getSerial(self):
         return self.serial
@@ -319,15 +321,6 @@ class PokerExplain:
                     game.setHandsCount(packet.hands_count)
                     game.setLevel(packet.level)
                     game.beginTurn(packet.hand_serial)
-                    if game.player_list_hint != None and game.player_list_hint != game.player_list:
-                        player_list_hint = set(game.player_list_hint)
-                        player_list = set(game.player_list)
-                        if not player_list_hint.issubset(player_list):
-                            raise ListHintSubset, "%s is not a subset of %s" % ( game.player_list_hint, game.player_list )
-                        if self.verbose >= 3:
-                            self.message("player_list_hint discards %s" % ( player_list_hint ^ player_list ))
-                        game.player_list = game.player_list_hint
-                    game.player_list_hint = None
                     game.position_info[PokerNetworkGameClient.POSITION_OBSOLETE] = True
                     if not self.no_display_packets:
                         forward_packets.append(PacketPokerBoardCards(game_id = game.id, serial = self.getSerial()))
@@ -348,15 +341,15 @@ class PokerExplain:
                 forward_packets.append(PacketPokerPosition(game_id = game.id))
 
             elif packet.type == PACKET_POKER_PLAYER_ARRIVE:
-                game.addPlayer(packet.serial, packet.seat)
-                player = game.getPlayer(packet.serial)
-                player.setUserData(DEFAULT_PLAYER_USER_DATA.copy())
-                player.name = packet.name
-                player.url = packet.url
-                player.outfit = packet.outfit
-                player.auto_blind_ante = packet.auto_blind_ante
-                player.wait_for = packet.wait_for
-                player.auto = packet.auto
+                if game.addPlayer(packet.serial, packet.seat):
+                    player = game.getPlayer(packet.serial)
+                    player.setUserData(DEFAULT_PLAYER_USER_DATA.copy())
+                    player.name = packet.name
+                    player.url = packet.url
+                    player.outfit = packet.outfit
+                    player.auto_blind_ante = packet.auto_blind_ante
+                    player.wait_for = packet.wait_for
+                    player.auto = packet.auto
                 if not self.no_display_packets:
                     self.forward_packets.append(PacketPokerSeats(game_id = game.id,
                                                                  seats = game.seats()))
@@ -426,7 +419,7 @@ class PokerExplain:
                 forward_packets.remove(packet)
 
             elif packet.type == PACKET_POKER_IN_GAME:
-                game.player_list_hint = packet.players[:]
+                game.setStaticPlayerList(packet.players)
                 for serial in game.serialsAll():
                     player = game.getPlayer(serial)
                     wait_for = player.wait_for
@@ -600,6 +593,12 @@ class PokerExplain:
                                                                       serial = player.serial,
                                                                       cards = cards))
 
+                if not self.no_display_packets:
+                    if game.isRunning() and game.cardsDealt() and self.getSerial() != 0 and game.isPlaying(self.getSerial()) and (packet.string == "flop" or packet.string == "turn" or packet.string == "river"):
+                        forward_packets.append(PacketPokerPlayerHandStrength(game_id = game.id,
+                                                                             serial = self.getSerial(),
+                                                                             hand = game.readablePlayerBestHands(self.getSerial())))
+
                 if ( packet.string != "end" and not game.isBlindAnteRound() ):
                     if not self.no_display_packets:
                         forward_packets.extend(self.updateBetLimit(game))
