@@ -34,10 +34,9 @@ import platform
 from os.path import exists
 from types import *
 
-from OpenSSL import SSL
-
 try:
         from OpenSSL import SSL
+        from pokernetwork.pokerservice import SSLContextFactory
         HAS_OPENSSL=True
 except:
         print "openSSL not available."
@@ -48,7 +47,7 @@ from twisted.application import internet, service, app
 from twisted.web import resource,server
 
 from pokernetwork.pokernetworkconfig import Config
-from pokernetwork.pokerservice import PokerTree, PokerRestTree, PokerService, IPokerFactory, SSLContextFactory
+from pokernetwork.pokerservice import PokerTree, PokerRestTree, PokerService, IPokerFactory
 from pokernetwork.pokersite import PokerSite
 from twisted.manhole import telnet
 
@@ -147,4 +146,5 @@ def run():
     reactor.run()
 
 if __name__ == '__main__':
-    run()
+    run() # pragma: no cover
+          # Do not need coverage since we call run directly in the tests.
