@@ -175,8 +175,17 @@ class Session(server.Session):
             # session already expired.
             #
             self.site.getSession(self.uid)
-            server.Session.checkExpired(self)
-            return True
+            #
+            # The session may be replaced by a new session as a side
+            # effect of the verifications made by getSession against
+            # memcache. When this happens no exception is thrown and
+            # checkExpired should not be called because the session
+            # has already expired.
+            #
+            if not self.expired:
+                server.Session.checkExpired(self)
+                return True
+            return False
         except KeyError:
             return False
         
@@ -199,6 +208,8 @@ class PokerResource(resource.Resource):
         jsonp = request.args.get('jsonp', [''])[0]
         if jsonp:
             data = request.args.get('packet', [''])[0]
+        elif request.args.has_key('packet'):
+            data = request.args['packet'][0];
         else:
             data = request.content.read()
         if self.verbose >= 3:
