@@ -3,6 +3,7 @@
 #
 # Copyright (C) 2006, 2007, 2008 Loic Dachary <loic@dachary.org>
 # Copyright (C)             2008 Bradley M. Kuhn <bkuhn@ebb.org>
+# Copyright (C)             2009 Johan Euphrosine <proppy@aminche.com>
 # Copyright (C) 2004, 2005, 2006 Mekensleep <licensing@mekensleep.com>
 #                                24 rue vieille du temple 75004 Paris
 #
@@ -84,8 +85,8 @@ class PokerTable:
 
         # max_missed_round can be configured on a per table basis, which
         # overrides the server-wide default
-        self.max_missed_round = description.get("max_missed_round",
-                                                factory.getMissedRoundMax())
+        self.max_missed_round = int(description.get("max_missed_round",
+                                                    factory.getMissedRoundMax()))
 
         self.delays = settings.headerGetProperties("/server/delays")[0]
         self.autodeal = settings.headerGet("/server/@autodeal") == "yes"
@@ -885,9 +886,10 @@ class PokerTable:
             game.getPlayer(serial).money = serial2chips[serial]
             game.sit(serial)
         if self.isJoined(client):
-            client.join(self)
+            client.join(self, reason = PacketPokerTable.REASON_HAND_REPLAY)
         else:
-            self.joinPlayer(client, client.getSerial())
+            self.joinPlayer(client, client.getSerial(),
+                            reason = PacketPokerTable.REASON_HAND_REPLAY)
         serial = client.getSerial()
         cache = self.createCache()
         for packet in self.history2packets(history, game.id, cache):
@@ -1033,7 +1035,7 @@ class PokerTable:
 
         return True
         
-    def movePlayer(self, client, serial, to_game_id):
+    def movePlayer(self, client, serial, to_game_id, reason = ""):
         game = self.game
         #
         # We are safe because called from within the server under
@@ -1055,10 +1057,11 @@ class PokerTable:
             self.error("movePlayer: player %d money %d in database, %d in memory" % ( serial, money_check, money ))
 
         if client:
-            client.join(other_table)
+            client.join(other_table, reason = reason)
         other_table.movePlayerTo(serial, money, sit_out)
         other_table.sendNewPlayerInformation(serial)
-        other_table.update()
+        if not other_table.update_recursion:
+            other_table.scheduleAutoDeal()
         if self.factory.verbose:
             self.message("player %d moved from table %d to table %d" % ( serial, game.id, to_game_id ))
 
@@ -1129,14 +1132,14 @@ class PokerTable:
         game.comeBack(serial)
         return True
             
-    def joinPlayer(self, client, serial):
+    def joinPlayer(self, client, serial, reason = ""):
         game = self.game
         #
         # Nothing to be done except sending all packets
         # Useful in disconnected mode to resume a session.
         #
         if self.isJoined(client):
-            client.join(self);
+            client.join(self, reason = reason);
             return True
 
         # Next, test to see if we have reached the server-wide maximum for
@@ -1162,7 +1165,7 @@ class PokerTable:
         # Player is now an observer, unless he is seated
         # at the table.
         #
-        client.join(self)
+        client.join(self, reason = reason)
         self.factory.joinedCountIncrease()
         if not self.game.isSeated(client.getSerial()):
             self.observers.append(client)
@@ -1236,6 +1239,7 @@ class PokerTable:
         self.broadcast(PacketPokerChat(game_id = self.game.id,
                                        serial = serial,
                                        message = message + "\n"))
+        self.factory.chatMessageArchive(serial, self.game.id, message)
 
     def autoBlindAnte(self, client, serial, auto):
         game = self.game
@@ -1272,6 +1276,7 @@ class PokerTable:
             self.observers.remove(client)
         else:
             del self.serial2client[serial]
+        assert client.tables.has_key(self.game.id), "bug#15016 player %d should be at table %d" % (serial, self.game.id)
         del client.tables[self.game.id]
         # FIXME: I don't think that PokerTable should be reaching into the
         #        member variables of the client classes.  Really the line
@@ -1385,7 +1390,7 @@ class PokerTable:
         if self.factory.verbose:
             self.message("muck timed out")
         # timer expires, force muck on muckables not responding
-        for serial in self.game.muckable_serials:
+        for serial in self.game.muckable_serials[:]:
             self.game.muck(serial, want_to_muck = True)
         self.cancelMuckTimer()
         self.update()
