@@ -115,71 +115,71 @@ if(_post_string('submit')) {
 		<table>
 			<tr>
 				<td></td>
-				<td><? echo _('Edit Account') ?></td>
+				<td><?php echo _('Edit Account') ?></td>
 			</tr>
 			<tr>
-				<td><b><? echo _('Login') ?><sup>*</sup>:</b></td>
+				<td><b><?php echo _('Login') ?><sup>*</sup>:</b></td>
 				<td><input type="hidden" id="name" name="name" value="<?php print $account['name'] ?>"><?php print $account['name'] ?></td>
 			</tr>
 			<tr>
-				<td><b><? echo _('New password') ?><sup>*</sup>:</b></td>
+				<td><b><?php echo _('New password') ?><sup>*</sup>:</b></td>
 				<td><input type="password" size="20" maxlength="32" id="password2" name="password2" /></td>
 			</tr>
 			<tr>
-				<td><b><? echo _('New Password confirmation') ?><sup>*</sup>:</b></td>
+				<td><b><?php echo _('New Password confirmation') ?><sup>*</sup>:</b></td>
 				<td><input type="password" size="20" maxlength="32" id="password3" name="password3" /></td>
 			</tr>
 			<tr>
-				<td><b><? echo _('Email') ?><sup>*</sup>:</b></td>
+				<td><b><?php echo _('Email') ?><sup>*</sup>:</b></td>
 				<td><input type="text" size="32" maxlength="128" id="email" name="email" value="<?php print $account['email'] ?>" /></td>
 			</tr>
 			<tr>
-				<td><b><? echo _('Phone') ?>:</b></td>
+				<td><b><?php echo _('Phone') ?>:</b></td>
 				<td><input type="text" size="40" maxlength="64" id="phone" name="phone" value="<?php print $account['phone'] ?>" /></td>
 			</tr>
 			<tr>
-				<td><b><? echo _('First Name') ?>:</b></td>
+				<td><b><?php echo _('First Name') ?>:</b></td>
 				<td><input type="text" size="32" maxlength="32" id="firstname" name="firstname" value="<?php print $account['firstname'] ?>" /></td>
 			</tr>
 			<tr>
-				<td><b><? echo _('Last Name') ?>:</b></td>
+				<td><b><?php echo _('Last Name') ?>:</b></td>
 				<td><input type="text" size="32" maxlength="32" id="lastname" name="lastname" value="<?php print $account['lastname'] ?>" /></td>
 			</tr>
 			<tr>
-				<td><b><? echo _('Gender') ?>:</b></td>
+				<td><b><?php echo _('Gender') ?>:</b></td>
 				<td>
 				<select id="gender" name="gender">
-                                <option value="M" <?php $account['gender'] == 'M' ? 'selected="selected"' : '' ?>><? echo _('Mr') ?></option>
-                                <option value="F" <?php $account['gender'] == 'F' ? 'selected="selected"' : '' ?>><? echo _('Miss') ?></option>
+                                <option value="M" <?php $account['gender'] == 'M' ? 'selected="selected"' : '' ?>><?php echo _('Mr') ?></option>
+                                <option value="F" <?php $account['gender'] == 'F' ? 'selected="selected"' : '' ?>><?php echo _('Miss') ?></option>
                                 </select>
                                 </td>
 			</tr>
 			<tr>
-			  <td><b><? echo _('Birthday') ?>:</b></td>
+			  <td><b><?php echo _('Birthday') ?>:</b></td>
                           <td><?php print $birthday->form(); ?></td>
 			</tr>
 			<tr>
-				<td><b><? echo _('Street') ?>:</b></td>
+				<td><b><?php echo _('Street') ?>:</b></td>
 				<td><textarea id="addr_street" name="addr_street" cols="30" rows="3"><?php print $account['addr_street'] ?></textarea></td>
 			</tr>
 			<tr>
-				<td><b><? echo _('Street') ?> 2:</b></td>
+				<td><b><?php echo _('Street') ?> 2:</b></td>
 				<td><textarea id="addr_street2" name="addr_street2" cols="30" rows="3"><?php print $account['addr_street2'] ?></textarea></td>
 			</tr>
 			<tr>
-				<td><b><? echo _('Zip code') ?>:</b></td>
+				<td><b><?php echo _('Zip code') ?>:</b></td>
 				<td><input type="text" size="20" maxlength="64" id="addr_zip" name="addr_zip" value="<?php print $account['addr_zip'] ?>" /></td>
 			</tr>
 			<tr>
-				<td><b><? echo _('Town') ?>:</b></td>
+				<td><b><?php echo _('Town') ?>:</b></td>
 				<td><input type="text" size="50" maxlength="64" id="addr_town" name="addr_town" value="<?php print $account['addr_town'] ?>" /></td>
 			</tr>
 			<tr>
-				<td><b><? echo _('State') ?>:</b></td>
+				<td><b><?php echo _('State') ?>:</b></td>
 				<td><input type="text" size="50" maxlength="128" id="addr_state" name="addr_state" value="<?php print $account['addr_state'] ?>" /></td>
 			</tr>
 			<tr>
-				<td><b><? echo _('Country') ?>:</b></td>
+				<td><b><?php echo _('Country') ?>:</b></td>
 				<td>
 					<select id="addr_country" name="addr_country">
 <?php
@@ -199,11 +199,11 @@ if(_post_string('submit')) {
 			<tr>
 				<td></td>
 				<td>
-                                        <img src="image.php?serial=<? print $serial ?>" />
-					<b><? echo _('Avatar') ?>: <input type="file" name="image"></b><br />
+                                        <img src="image.php?serial=<?php print $serial ?>" />
+					<b><?php echo _('Avatar') ?>: <input type="file" name="image"></b><br />
 				<td></td>
 				<td>
-					<input type="submit" name='submit' value="<? echo _('Ok') ?>" />
+					<input type="submit" name='submit' value="<?php echo _('Ok') ?>" />
 				</td>
 			</tr>
 		</table>
