@@ -1,26 +1,23 @@
 /*
 *
-* Copyright (C) 2006 Mekensleep
-*
-*	Mekensleep
-*	24 rue vieille du temple
-*	75004 Paris
-* licensing@mekensleep.com
-*
-* This program is free software; you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation; either version 3 of the License, or
-* (at your option) any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program; if not, write to the Free Software
-* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA.
-*
+* Copyright (C) 2006 Mekensleep <licensing@mekensleep.com>
+*                    24 rue vieille du temple, 75004 Paris
+ *
+ * This software's license gives you freedom; you can copy, convey,
+ * propagate, redistribute and/or modify this program under the terms of
+ * the GNU Affero General Public License (AGPL) as published by the Free
+ * Software Foundation (FSF), either version 3 of the License, or (at your
+ * option) any later version of the AGPL published by the FSF.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program in a file in the toplevel directory called
+ * "AGPLv3".  If not, see <http://www.gnu.org/licenses/>.
+ *
 * Authors:
 *  Jerome Jeannin <griim.work@gmail.com>
 *
